@@ -7,12 +7,14 @@ from bentoudev.dataclass.base import loaded_from_file, track_source
 @dataclass
 @track_source
 class ProjectConfig:
-    verbose_build: bool = False
+    verbose_build: Optional[bool] = False
+    dev_profile: str = ''
     platforms: List[str] = field(default_factory=list)
     configurations: List[str] = field(default_factory=list)
+    cli_tools: Optional[List[str]] = field(default_factory=list)
     # slots: Optional[List[str]] = field(default_factory=list)
     rules: Optional[List[str]] = field(default_factory=list)
-    config_string: str = ''
+    config_string: Optional[str] = '{platform}-{configuration}-{toolchain}'
     venv: Optional[str] = ''
 
 
