@@ -1,5 +1,5 @@
 from typing import List
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from zetsubou.project.model.filter import TargetFilter
 from zetsubou.project.model.target import TargetData
 from bentoudev.dataclass.base import loaded_from_file
@@ -7,7 +7,7 @@ from bentoudev.dataclass.base import loaded_from_file
 
 @dataclass
 class RuleData(TargetData):
-    filter: TargetFilter = TargetFilter()
+    filter: TargetFilter = field(default_factory=TargetFilter)
 
 
 @dataclass
